@@ -6,15 +6,15 @@ class Secrets:
   def __init__(self, conn: Connection):
     self.conn = conn
 
-  async def revoke(self, secret_id):
+  async def revoke_service_secret(self, secret_id):
     result = await self.conn.query_control(
       variables={
         'secretID': secret_id,
       },
       query="""
-        mutation RevokeSecret($secretID: UUID!) {
-          revokeSecret(secretID: $secretID)
+        mutation RevokeServiceSecret($secretID: UUID!) {
+          revokeServiceSecret(secretID: $secretID)
         }
       """
     )
-    return result['revokeSecret']
+    return result['revokeServiceSecret']
