@@ -1,4 +1,4 @@
-from typing import AsyncIterator, List
+from typing import AsyncIterator
 import uuid
 import warnings
 
@@ -15,6 +15,7 @@ from beneath.proto import gateway_pb2_grpc
 
 
 class GraphQLError(Exception):
+  """ Error returned for control-plane (GraphQL) errors """
 
   def __init__(self, message, errors):
     super().__init__(message)
@@ -22,9 +23,7 @@ class GraphQLError(Exception):
 
 
 class AuthenticationError(Exception):
-
-  def __init__(self, message):
-    super().__init__(message)
+  """ Error returned for failed authentication """
 
 
 class Connection:
@@ -57,16 +56,16 @@ class Connection:
       self._create_grpc_connection()
       try:
         await self._check_grpc_connection()
-      except grpc.RpcError as e:
-        if e.code() == grpc.StatusCode.UNAUTHENTICATED:
-          raise AuthenticationError(e.details()) from e
-        raise e
+      except grpc.RpcError as exc:
+        # pylint: disable=no-member
+        if exc.code() == grpc.StatusCode.UNAUTHENTICATED:
+          raise AuthenticationError(exc.details()) from exc
+        raise exc
       self.connected = True
 
   def _create_grpc_connection(self):
     self.request_metadata = [('authorization', 'Bearer {}'.format(self.secret))]
     insecure = "localhost" in config.BENEATH_GATEWAY_HOST_GRPC
-    insecure = insecure or config.INTERNAL_NETWORK
     if insecure:
       self.channel = aiogrpc.insecure_channel(
         target=config.BENEATH_GATEWAY_HOST_GRPC,
@@ -138,13 +137,10 @@ class Connection:
 
   # DATA-PLANE
 
-  async def write(self, instance_id: uuid.UUID, records: List[gateway_pb2.Record]) -> gateway_pb2.WriteResponse:
+  async def write(self, instance_records: gateway_pb2.InstanceRecords) -> gateway_pb2.WriteResponse:
     await self.ensure_connected()
     return await self.stub.Write(
-      gateway_pb2.WriteRequest(
-        instance_id=instance_id.bytes,
-        records=records,
-      ),
+      gateway_pb2.WriteRequest(instance_records=instance_records),
       metadata=self.request_metadata,
     )
 
@@ -171,20 +167,19 @@ class Connection:
       metadata=self.request_metadata,
     )
 
-  async def read(self, instance_id: uuid.UUID, cursor: bytes, limit: int) -> gateway_pb2.ReadResponse:
+  async def read(self, cursor: bytes, limit: int) -> gateway_pb2.ReadResponse:
     await self.ensure_connected()
     return await self.stub.Read(
       gateway_pb2.ReadRequest(
-        instance_id=instance_id.bytes,
         cursor=cursor,
         limit=limit,
       ),
       metadata=self.request_metadata,
     )
 
-  async def subscribe(self, instance_id: uuid.UUID, cursor: bytes) -> AsyncIterator[gateway_pb2.SubscribeResponse]:
+  async def subscribe(self, cursor: bytes) -> AsyncIterator[gateway_pb2.SubscribeResponse]:
     await self.ensure_connected()
     return self.stub.Subscribe(
-      gateway_pb2.SubscribeRequest(instance_id=instance_id.bytes, cursor=cursor),
+      gateway_pb2.SubscribeRequest(cursor=cursor),
       metadata=self.request_metadata,
     )
